a tool to add, delete, list model versioning for cloud provider

Usage: modelver-cli [OPTIONS] COMMAND [ARGS]...

Options:
  --help  Show this message and exit.

Commands:
  add_directory    add directory files to project model version storage
  add_file         add files to project model version storage
  configure        configure cloud provider bucket name and project for google, should be done from root directory
  configure_cloud  configure cloud provider, should be done from root directory
  del_file         delete specific file from storage
  del_ver          delete ver for project
  display_config   display the content of configuration file
  get_file         get specific fie from storage
  get_ver          get complete version files for specific project
  ls               list storage content, no argument list projects
  print_ver        display ver for project



Currently, supports only google cloud provider,